package com.ozs.web.controller.plan;

import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.core.domain.model.LoginUser;
import com.ozs.common.core.page.TableDataInfo;
import com.ozs.framework.web.service.TokenService;
import com.ozs.plan.doman.PlanOfYears;
import com.ozs.plan.doman.vo.requestVo.PlanOfYearsStandardVo;
import com.ozs.plan.doman.vo.responseVo.PlanOfYearsResponseVo;
import com.ozs.plan.service.PlanOfYearsService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 年度计划信息控制层
 *
 * @author buzhanyi
 */
@RestController
@RequestMapping("/plan/planOfYears")
public class PlanOfYearsController extends BaseController {
    @Autowired
    private PlanOfYearsService planOfYearsService;
    @Autowired
    private TokenService tokenService;

    @ApiOperation(value = "查询年度计划")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody PlanOfYearsStandardVo yearsStandardVo) {
        startPage();
        List<PlanOfYears> list = planOfYearsService.selectPlanOfYearsList(yearsStandardVo);
        return getDataTable(list);
    }

    @ApiOperation(value = "创建年度计划")
    @PostMapping("/add")
    public AjaxResult add(@RequestBody PlanOfYearsStandardVo yearsStandardVo, HttpServletRequest request) {
        //获取采购单位-
        LoginUser loginUser = tokenService.getLoginUser(request);
        yearsStandardVo.setPurchaseUnit(loginUser.getDeptId());
        yearsStandardVo.setCreateBy(String.valueOf(loginUser.getUserId()));
        return planOfYearsService.insertPlanOfYears(yearsStandardVo);
    }

    @ApiOperation(value = "修改年度计划")
    @PostMapping("/update")
    public AjaxResult update(@RequestBody PlanOfYearsStandardVo yearsStandardVo) {
        return planOfYearsService.update(yearsStandardVo);
    }

    @ApiOperation(value = "删除年度计划")
    @PostMapping("/delete")
    public AjaxResult delete(@RequestBody PlanOfYearsStandardVo yearsStandardVo) {
        return planOfYearsService.deletePlanOfYearsById(yearsStandardVo.getPlanYearId());
    }

    //@ApiOperation(value = "删除年度计划")
    //@PostMapping("/delete")
    //public AjaxResult delete(@RequestBody Long[] planIds) {
    //    return planOfYearsService.deletePlanOfYearsByIds(planIds);
    //}

    @ApiOperation(value = "根据id获取年度计划信息")
    @PostMapping("/view")
    public AjaxResult view(@RequestBody PlanOfYearsStandardVo yearsStandardVo) {
        return planOfYearsService.view(yearsStandardVo);
    }


}
