package com.ozs.plan.service.impl;

import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.enums.ProjectStatus;
import com.ozs.common.utils.bean.BeanUtils;
import com.ozs.plan.doman.PlanOfYears;
import com.ozs.plan.doman.vo.requestVo.PlanOfYearsStandardVo;
import com.ozs.plan.doman.vo.responseVo.PlanOfYearsResponseVo;
import com.ozs.plan.mapper.PlanOfYearsMapper;
import com.ozs.plan.service.PlanOfYearsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author buzhanyi
 */
@Service
public class PlanOfYearsServiceImpl implements PlanOfYearsService {

    @Autowired
    PlanOfYearsMapper planOfYearsMapper;

    @Override
    public List<PlanOfYears> selectPlanOfYearsList(PlanOfYearsStandardVo vo) {
        PlanOfYears ofYears = new PlanOfYears();
        List<PlanOfYears> planOfYears = new ArrayList<>();
        try {
            BeanUtils.copyProperties(vo, ofYears);
            planOfYears = planOfYearsMapper.selectPlanOfYearsList(ofYears);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return planOfYears;
    }

    @Override
    public AjaxResult insertPlanOfYears(PlanOfYearsStandardVo yearsStandardVo) {
        if (planOfYearsMapper.countProjectName(yearsStandardVo.getProjectName()) > 0) {
            return AjaxResult.error("该项目名称已经存在");
        }
        PlanOfYears ofYears = new PlanOfYears();
        try {
            BeanUtils.copyProperties(yearsStandardVo, ofYears);
        } catch (Exception e) {
            e.printStackTrace();
        }
        //判断是否为超额计划---

        ofYears.setProjectStatus(ProjectStatus.PLANWAITCOMMIT.getCode());
        ofYears.setCreateTime(new Date());
        planOfYearsMapper.insertPlanOfYears(ofYears);
        return AjaxResult.success();
    }

    @Override
    public AjaxResult deletePlanOfYearsByIds(Long[] planIds) {
        planOfYearsMapper.deletePlanOfYearsByIds(planIds);
        return AjaxResult.success();
    }

    @Override
    public AjaxResult deletePlanOfYearsById(Long planId) {
        planOfYearsMapper.deletePlanOfYearsById(planId);
        return AjaxResult.success();
    }

    @Override
    public AjaxResult view(PlanOfYearsStandardVo yearsStandardVo) {
        PlanOfYears byId = planOfYearsMapper.getById(yearsStandardVo.getPlanYearId());
        if (byId == null) {
            return AjaxResult.error("数据查询失败");
        }
        return AjaxResult.success(byId);
    }

    @Override
    public AjaxResult update(PlanOfYearsStandardVo yearsStandardVo) {
        if (planOfYearsMapper.countProjectNameOther(yearsStandardVo.getProjectName(), String.valueOf(yearsStandardVo.getPlanYearId())) > 0) {
            return AjaxResult.error("该项目名称已经存在");
        }
        PlanOfYears ofYears = new PlanOfYears();
        try {
            BeanUtils.copyProperties(yearsStandardVo, ofYears);
        } catch (Exception e) {
            e.printStackTrace();
        }
        planOfYearsMapper.updateById(ofYears);
        return AjaxResult.success();
    }

}
